Learn R Programming

mistat (version 1.0-3)

OTURB2: Sample Mean and Standard Deviation of Cycle Times of a Piston

Description

In this data frame we have three variables. In the first we have the sample size. In the second and third we have the sample means and standard deviation.

Usage

data(OTURB2)

Arguments

Format

A data frame with 10 observations on the following 3 variables.
groupSize
a numeric vector
xbar
a numeric vector
std
a numeric vector

Kenett, R. and Zacks, S. (1998) Modern Industrial Statistics: The Design and Control of Quality and Reliability. Duxbury Press.

Examples

Run this code
data(OTURB2)
plot(OTURB2$xbar, type="b")
plot(OTURB2$std, type="b")

Run the code above in your browser using DataLab